Flower - Celery monitoring tool — Flower 1.0.1 documentation

# Flower - Celery monitoring tool

Flower is a web based tool for monitoring and administrating Celery clusters

## Features

- Real-time monitoring using Celery Events

  > - Task progress and history

  > - Ability to show task details (arguments, start time, runtime, and more)

  > - Graphs and statistics

- Remote Control

  > - View worker status and statistics

  > - Shutdown and restart worker instances

  > - Control worker pool size and autoscale settings

  > - View and modify the queues a worker instance consumes from

  > - View currently running tasks

  > - View scheduled tasks (ETA/countdown)

  > - View reserved and revoked tasks

  > - Apply time and rate limits

  > - Configuration viewer

  > - Revoke or terminate tasks

- Broker monitoring

  > - View statistics for all Celery queues

  > - Queue length graphs

- HTTP API

- Basic Auth, GitHub OAuth2 and Google OpenID authentication

- Prometheus integration

### Contents

- Features
- Screenshots
- Installation
  - Usage
- Configuration
  - Options
- Tasks filtering
  - Task filter syntax
- API Reference
- Authentication
  - HTTP Basic Authentication
  - Google OAuth 2.0
  - Okta OAuth
  - GitHub OAuth
  - GitLab OAuth
- Running behind reverse proxy
- Docker Usage

Flower is Open Source and licensed under the BSD License.